@@ -1,5 +1,7 @@
-context("Empty columns")
-
+context("Empty columns 1.8.0")
+if (requireNamespace("hutilscpp", quietly = TRUE)) {
+  options(hutils.test_no_hutilscpp = TRUE)
+}
 test_that("Drops empty columns of data.tables and data.frames", {
   library(data.table)
   DT1 <- data.table(x1 = 1:5,
